"""
    verktyg_server.tests.test_argparse
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    :copyright:
        (c) 2015 by Ben Mather.
    :license:
        BSD, see LICENSE for more details.
"""
import unittest
import argparse

from verktyg_server.argparse import add_arguments

import logging
logging.disable(logging.CRITICAL)


class ParseError(Exception):
    pass


class SilentArgumentParser(argparse.ArgumentParser):
    def error(self, message):
        raise ParseError(message)


class ArgParseTestCase(unittest.TestCase):
    def test_socket(self):
        parser = SilentArgumentParser()

        add_arguments(parser)

        options = parser.parse_args('--socket /path/to/socket'.split())

        self.assertEqual(options.socket, '/path/to/socket')
        self.assertIsNone(options.address)
        self.assertIsNone(options.fd)
        self.assertIsNone(options.certificate)
        self.assertIsNone(options.private_key)

    def test_mutual_exclusion(self):
        parser = SilentArgumentParser()
        add_arguments(parser)

        with self.assertRaises(ParseError):
            parser.parse_args(
                '--socket socket --address address'.split()
            )

    def test_address(self):
        parser = SilentArgumentParser()
        add_arguments(parser)

        options = parser.parse_args(
            '--address http://example.com:8000'.split()
        )
        self.assertEqual(options.address.scheme, 'http')
        self.assertEqual(options.address.hostname, 'example.com')
        self.assertEqual(options.address.port, 8000)

    def test_private_key_only(self):
        parser = SilentArgumentParser()
        add_arguments(parser)

        with self.assertRaises(ParseError):
            parser.parse_args(
                '--address address --private-key path/to/key_file.pem'
            )



"""
Verktyg Server
==============

Simple WSGI server.
"""
from setuptools import setup, find_packages


extras_require = {
    'SSL': [
        'cryptography',
    ]
}


setup(
    name='verktyg-server',
    version='0.1.3',
    url='https://github.com/bwhmather/verktyg-server',
    license='BSD',
    author='Ben Mather',
    author_email='bwhmather@bwhmather.com',
    description='Simple wsgi server',
    long_description=__doc__,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    platforms='any',
    install_requires=[
        'verktyg >= 0.8, < 0.9',
    ],
    tests_require=[
        test for extra in {'SSL'} for test in extras_require[extra]
    ],
    extras_require=extras_require,
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'verktyg-server=verktyg_server:main',
        ],
    },
    include_package_data=True,
    test_suite='verktyg_server.tests.suite',
)
